[![Anaconda-Server Badge](https://anaconda.org/scipp/scippneutron/badges/version.svg)](https://anaconda.org/scipp/scippneutron)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)
[![Release build](https://github.com/scipp/scipp/actions/workflows/release.yml/badge.svg)](https://github.com/scipp/scippneutron/actions/workflows/release.yml)

# scippneutron

## About

Neutron scattering toolkit built using [scipp](https://github.com/scipp/scipp) for Data Reduction.
See the [documentation](https://scipp.github.io/scippneutron/) for details.

This serves as a foundation for facility and instrument specific functionality such as that available in [ess](https://github.com/scipp/ess).

## Development

If you are interested in developing Scippneutron, please see the [developer getting started guide](https://scipp.github.io/scippneutron/developer/getting-started.html).

## Contributing Organizations

The following organizations have made major contributions to the development of scippneutron and other developments in the [scipp ecosystem](../../../):

* [European Spallation Source ERIC](https://europeanspallationsource.se/), Sweden
* [Science and Technology Facilities Council](https://www.ukri.org/councils/stfc/), UK

See individual [release notes](https://scipp.github.io/scippneutron/about/release-notes.html) for the individual contributors to each release.
